==> react-lds-8.7.0.tgz: package/es/components/GroupedCombobox/ComboboxGroupedListbox/index.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Icon } from '../../Icon';
import { Button } from '../../Button';
import { Listbox, Pill } from '../../Pill';
import { OverflowContainer } from './OverflowContainer';

var isPropChanged = function isPropChanged(prop) {
  return function (a, b) {
    return a[prop] !== b[prop];
  };
};

var isLengthChanged = isPropChanged('length');
var isIdChanged = isPropChanged('id');
var isOpenChanged = isPropChanged('isOpen');

var ComboboxGroupedListbox =
/*#__PURE__*/
function (_Component) {
  _inherits(ComboboxGroupedListbox, _Component);

  function ComboboxGroupedListbox(props) {
    var _this;

    _classCallCheck(this, ComboboxGroupedListbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ComboboxGroupedListbox).call(this, props));
    _this.state = {
      forcedUpdateTimestamp: null
    };
    _this.listboxRef = React.createRef();
    return _this;
  }

  _createClass(ComboboxGroupedListbox, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var _this$props = this.props,
          selectedItems = _this$props.selectedItems,
          isExpanded = _this$props.isExpanded;
      var prevSelectedItems = prevProps.selectedItems;
      if (isExpanded) return;

      if (isOpenChanged(this.props, prevProps) || isLengthChanged(selectedItems, prevSelectedItems)) {
        this.forceRecalculation();
        return;
      } // Optimization: Lists longer than 30 items will have an overflow present
      // We can skip a detailed check and assume that only a length change should trigger a recalculation


      if (selectedItems.length < 30 && selectedItems.some(function (item, i) {
        return isIdChanged(item, prevSelectedItems[i]);
      })) {
        this.forceRecalculation();
      }
    }
  }, {
    key: "forceRecalculation",
    value: function forceRecalculation() {
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState({
        forcedUpdateTimestamp: Date.now()
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          hideWhenEmpty = _this$props2.hideWhenEmpty,
          isExpanded = _this$props2.isExpanded,
          isOpen = _this$props2.isOpen,
          label = _this$props2.label,
          makeSelectHandler = _this$props2.makeSelectHandler,
          onExpand = _this$props2.onExpand,
          overflowLabel = _this$props2.overflowLabel,
          renderPill = _this$props2.renderPill,
          selectedItems = _this$props2.selectedItems,
          showItemsWhenOpen = _this$props2.showItemsWhenOpen;
      var forcedUpdateTimestamp = this.state.forcedUpdateTimestamp;
      var sldsClasses = ['slds-listbox_selection-group', {
        'slds-is-expanded': isExpanded
      }, {
        'slds-hide': hideWhenEmpty && selectedItems.length === 0 || isOpen && !showItemsWhenOpen
      }];
      var makeExpandButtonTitle = typeof overflowLabel === 'function' ? overflowLabel : function () {
        return overflowLabel;
      };
      return React.createElement(OverflowContainer, {
        containerRef: this.listboxRef,
        forcedUpdateTimestamp: forcedUpdateTimestamp,
        skipCalculation: isExpanded || isOpen
      }, function (_ref) {
        var overflowCount = _ref.overflowCount;
        return React.createElement("div", {
          className: cx(sldsClasses)
        }, !isExpanded && overflowCount > 0 && React.createElement("span", {
          className: "slds-listbox-toggle",
          "aria-hidden": "true"
        }, React.createElement(Button, {
          tabIndex: "-1",
          flavor: "none",
          onClick: onExpand,
          title: makeExpandButtonTitle(overflowCount)
        })), React.createElement(Listbox, {
          label: label,
          ref: _this2.listboxRef
        }, selectedItems.map(function (_ref2) {
          var icon = _ref2.icon,
              id = _ref2.id,
              itemLabel = _ref2.label,
              rest = _objectWithoutProperties(_ref2, ["icon", "id", "label"]);

          var pillProps = _objectSpread({}, rest, {
            key: id,
            icon: icon ? React.createElement(Icon, {
              icon: icon.icon,
              sprite: icon.sprite
            }) : null,
            label: itemLabel,
            title: itemLabel,
            onClose: makeSelectHandler(id)
          });

          return renderPill ? renderPill(pillProps) : React.createElement(Pill, pillProps);
        })));
      });
    }
  }]);

  return ComboboxGroupedListbox;
}(Component);

_defineProperty(ComboboxGroupedListbox, "defaultProps", {
  hideWhenEmpty: false,
  isExpanded: false,
  overflowLabel: function overflowLabel(cnt) {
    return "+".concat(cnt, " more");
  },
  renderPill: null,
  showItemsWhenOpen: false
});

ComboboxGroupedListbox.propTypes = process.env.NODE_ENV !== "production" ? {
  isExpanded: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  hideWhenEmpty: PropTypes.bool,
  label: PropTypes.string.isRequired,
  makeSelectHandler: PropTypes.func.isRequired,
  onExpand: PropTypes.func.isRequired,
  overflowLabel: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  renderPill: PropTypes.func,
  selectedItems: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })).isRequired,
  showItemsWhenOpen: PropTypes.bool
} : {};
export default ComboboxGroupedListbox;

==> react-lds-9.1.0.tgz: package/es/components/GroupedCombobox/ComboboxGroupedListbox/index.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.array.some";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.for-each";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { Icon } from '../../Icon';
import { Button } from '../../Button';
import { Listbox, Pill } from '../../Pill';
import { OverflowContainer } from './OverflowContainer';

var isPropChanged = function isPropChanged(prop) {
  return function (a, b) {
    return a[prop] !== b[prop];
  };
};

var isLengthChanged = isPropChanged('length');
var isIdChanged = isPropChanged('id');
var isOpenChanged = isPropChanged('isOpen');

var ComboboxGroupedListbox =
/*#__PURE__*/
function (_Component) {
  _inherits(ComboboxGroupedListbox, _Component);

  function ComboboxGroupedListbox(props) {
    var _this;

    _classCallCheck(this, ComboboxGroupedListbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(ComboboxGroupedListbox).call(this, props));
    _this.state = {
      forcedUpdateTimestamp: null
    };
    _this.listboxRef = React.createRef();
    return _this;
  }

  _createClass(ComboboxGroupedListbox, [{
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var _this$props = this.props,
          selectedItems = _this$props.selectedItems,
          isExpanded = _this$props.isExpanded;
      var prevSelectedItems = prevProps.selectedItems;
      if (isExpanded) return;

      if (isOpenChanged(this.props, prevProps) || isLengthChanged(selectedItems, prevSelectedItems)) {
        this.forceRecalculation();
        return;
      } // Optimization: Lists longer than 30 items will have an overflow present
      // We can skip a detailed check and assume that only a length change should trigger a recalculation


      if (selectedItems.length < 30 && selectedItems.some(function (item, i) {
        return isIdChanged(item, prevSelectedItems[i]);
      })) {
        this.forceRecalculation();
      }
    }
  }, {
    key: "forceRecalculation",
    value: function forceRecalculation() {
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState({
        forcedUpdateTimestamp: Date.now()
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          hideWhenEmpty = _this$props2.hideWhenEmpty,
          isExpanded = _this$props2.isExpanded,
          isOpen = _this$props2.isOpen,
          label = _this$props2.label,
          makeSelectHandler = _this$props2.makeSelectHandler,
          onExpand = _this$props2.onExpand,
          overflowLabel = _this$props2.overflowLabel,
          renderPill = _this$props2.renderPill,
          selectedItems = _this$props2.selectedItems,
          showItemsWhenOpen = _this$props2.showItemsWhenOpen;
      var forcedUpdateTimestamp = this.state.forcedUpdateTimestamp;
      var sldsClasses = ['slds-listbox_selection-group', {
        'slds-is-expanded': isExpanded
      }, {
        'slds-hide': hideWhenEmpty && selectedItems.length === 0 || isOpen && !showItemsWhenOpen
      }];
      var makeExpandButtonTitle = typeof overflowLabel === 'function' ? overflowLabel : function () {
        return overflowLabel;
      };
      return React.createElement(OverflowContainer, {
        containerRef: this.listboxRef,
        forcedUpdateTimestamp: forcedUpdateTimestamp,
        skipCalculation: isExpanded || isOpen
      }, function (_ref) {
        var overflowCount = _ref.overflowCount;
        return React.createElement("div", {
          className: cx(sldsClasses)
        }, !isExpanded && overflowCount > 0 && React.createElement("span", {
          className: "slds-listbox-toggle",
          "aria-hidden": "true"
        }, React.createElement(Button, {
          tabIndex: "-1",
          flavor: "none",
          onClick: onExpand,
          title: makeExpandButtonTitle(overflowCount)
        })), React.createElement(Listbox, {
          label: label,
          ref: _this2.listboxRef
        }, selectedItems.map(function (_ref2) {
          var icon = _ref2.icon,
              id = _ref2.id,
              itemLabel = _ref2.label,
              rest = _objectWithoutProperties(_ref2, ["icon", "id", "label"]);

          var pillProps = _objectSpread({}, rest, {
            key: id,
            icon: icon ? React.createElement(Icon, {
              icon: icon.icon,
              sprite: icon.sprite
            }) : null,
            label: itemLabel,
            title: itemLabel,
            onClose: makeSelectHandler(id)
          });

          return renderPill ? renderPill(pillProps) : React.createElement(Pill, pillProps);
        })));
      });
    }
  }]);

  return ComboboxGroupedListbox;
}(Component);

_defineProperty(ComboboxGroupedListbox, "defaultProps", {
  hideWhenEmpty: false,
  isExpanded: false,
  overflowLabel: function overflowLabel(cnt) {
    return "+".concat(cnt, " more");
  },
  renderPill: null,
  showItemsWhenOpen: false
});

ComboboxGroupedListbox.propTypes = process.env.NODE_ENV !== "production" ? {
  isExpanded: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  hideWhenEmpty: PropTypes.bool,
  label: PropTypes.string.isRequired,
  makeSelectHandler: PropTypes.func.isRequired,
  onExpand: PropTypes.func.isRequired,
  overflowLabel: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  renderPill: PropTypes.func,
  selectedItems: PropTypes.arrayOf(PropTypes.shape({
    id: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })).isRequired,
  showItemsWhenOpen: PropTypes.bool
} : {};
export default ComboboxGroupedListbox;
